"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.standardAddressHash = exports.fillWithDefault = exports.defaultMccLoggingObject = exports.defaultExceptionCallback = exports.defaultWarningCallback = exports.defaultLoggingCallback = exports.mccJsonStringify = exports.bytesAsHexToString = exports.isValidHexString = exports.isValidBytes32HexPrefix = exports.isValidBytes32Hex = exports.toHex32Bytes = exports.hexToBytes = exports.toHex = exports.isPrefixed0x = exports.prefix0x = exports.unPrefix0x = exports.sleepMs = exports.getSimpleRandom = exports.MccError = exports.ZERO_BYTES_32 = void 0;
/* eslint-disable @typescript-eslint/no-explicit-any */
const util_1 = require("util");
const web3_utils_1 = require("web3-utils");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const safeStringify = require("fast-safe-stringify");
exports.ZERO_BYTES_32 = "0x0000000000000000000000000000000000000000000000000000000000000000";
function MccError(error) {
    try {
        const message = mccJsonStringify(error);
        return new Error(message);
    }
    catch (thisError) {
        return new Error(`MCC stringify error ${thisError}`);
    }
}
exports.MccError = MccError;
function getSimpleRandom(maxnum) {
    return Math.floor(Math.random() * maxnum);
}
exports.getSimpleRandom = getSimpleRandom;
async function sleepMs(ms) {
    await new Promise((resolve) => setTimeout(() => resolve(), ms));
}
exports.sleepMs = sleepMs;
function unPrefix0x(tx) {
    if (!tx) {
        return "0x0";
    }
    return tx.startsWith("0x") ? tx.slice(2) : tx;
}
exports.unPrefix0x = unPrefix0x;
function prefix0x(tx) {
    if (!tx) {
        return "0x0";
    }
    return tx.startsWith("0x") ? tx : "0x" + tx;
}
exports.prefix0x = prefix0x;
function isPrefixed0x(tx) {
    if (!tx) {
        return false;
    }
    return tx.startsWith("0x") ? true : false;
}
exports.isPrefixed0x = isPrefixed0x;
function toHex(x) {
    return (0, web3_utils_1.toHex)(Number(x));
}
exports.toHex = toHex;
// Convert a hex string to a byte array (???ALGO SPECIFIC???)
function hexToBytes(hex) {
    const bytes = [];
    for (let c = 0; c < hex.length; c += 2)
        bytes.push(parseInt(hex.substr(c, 2), 16));
    return new Uint8Array(bytes);
}
exports.hexToBytes = hexToBytes;
function toHex32Bytes(x) {
    return (0, web3_utils_1.padLeft)(toHex(x), 64);
}
exports.toHex32Bytes = toHex32Bytes;
function isValidBytes32Hex(address) {
    return /^(0x|0X)?[0-9a-fA-F]{64}$/i.test(address);
}
exports.isValidBytes32Hex = isValidBytes32Hex;
function isValidBytes32HexPrefix(address) {
    return /^(0x|0X)?[0-9a-fA-F]{64}$/i.test(address);
}
exports.isValidBytes32HexPrefix = isValidBytes32HexPrefix;
function isValidHexString(maybeHexString) {
    return /^(0x|0X)?[0-9a-fA-F]*$/i.test(maybeHexString);
}
exports.isValidHexString = isValidHexString;
////////////////////////////////////////////////////////////////////////////////////////////////////
////////// bytes to string (utf8) decoder //////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////
const decoder = new util_1.TextDecoder("UTF-8");
// Bytes as hex string to string
function bytesAsHexToString(bytesString) {
    if (isValidHexString(bytesString)) {
        const array = new Uint8Array(hexToBytes(unPrefix0x(bytesString)));
        return prefix0x(decoder.decode(array));
    }
    return "";
}
exports.bytesAsHexToString = bytesAsHexToString;
////////////////////////////////////////////////////////////////////////////////////////////////////
////////// json stringify wrapper //////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////
function mccJsonStringify(toStringify) {
    const options = {
        depthLimit: 2,
        edgesLimit: 3,
    };
    return safeStringify(toStringify, null, 2, options);
}
exports.mccJsonStringify = mccJsonStringify;
////////////////////////////////////////////////////////////////////////////////////////////////////
////////// Default logging and exception callbacks /////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////
function defaultLoggingCallback(message) {
    console.log(message);
}
exports.defaultLoggingCallback = defaultLoggingCallback;
function defaultWarningCallback(message) {
    console.log(message);
}
exports.defaultWarningCallback = defaultWarningCallback;
function defaultExceptionCallback(error, message) {
    console.log(message);
    console.error(error);
    if (error.stack) {
        console.error(error.stack);
    }
}
exports.defaultExceptionCallback = defaultExceptionCallback;
function defaultMccLoggingObject() {
    return {
        mode: "develop",
        loggingCallback: defaultLoggingCallback,
        warningCallback: defaultWarningCallback,
        exceptionCallback: defaultExceptionCallback,
    };
}
exports.defaultMccLoggingObject = defaultMccLoggingObject;
function fillWithDefault(partialMccLogging) {
    return {
        mode: partialMccLogging.mode ? partialMccLogging.mode : "develop",
        loggingCallback: partialMccLogging.loggingCallback ? partialMccLogging.loggingCallback : defaultLoggingCallback,
        warningCallback: partialMccLogging.warningCallback ? partialMccLogging.warningCallback : defaultWarningCallback,
        exceptionCallback: partialMccLogging.exceptionCallback ? partialMccLogging.exceptionCallback : defaultExceptionCallback,
    };
}
exports.fillWithDefault = fillWithDefault;
////////////////////////////////////////////////////////////////////////////////////////////////////
////////// Standard address Hash ///////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////
function standardAddressHash(address) {
    return (0, web3_utils_1.keccak256)(address);
}
exports.standardAddressHash = standardAddressHash;
//# sourceMappingURL=utils.js.map