"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const src_1 = require("../../src");
const testUtils_1 = require("../testUtils");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const stdout = require("test-console").stdout;
// eslint-disable-next-line @typescript-eslint/no-var-requires
const stderr = require("test-console").stderr;
// eslint-disable-next-line @typescript-eslint/no-var-requires
const chai = require("chai");
// eslint-disable-next-line @typescript-eslint/no-var-requires
chai.use(require("chai-as-promised"));
describe(`Utils tests ,(${(0, testUtils_1.getTestFile)(__filename)})`, () => {
    it("should return '0x0' if no tx", () => {
        const expected = "0x0";
        const res = (0, src_1.unPrefix0x)("");
        (0, chai_1.expect)(res).to.be.equal(expected);
    });
    it("should return false if no tx", () => {
        const res = (0, src_1.isPrefixed0x)("");
        (0, chai_1.expect)(res).to.be.false;
    });
    it("should return hex 2022 as string", () => {
        (0, chai_1.expect)((0, src_1.toHex)("2022")).to.be.eq("0x7e6");
    });
    it("should return hex 10 as string", () => {
        (0, chai_1.expect)((0, src_1.toHex)("10")).to.be.eq("0xa");
    });
    it("should return hex 2022 as number", () => {
        (0, chai_1.expect)((0, src_1.toHex)(2022)).to.be.eq("0x7e6");
    });
    it("should return defaultMccLoggingObject", () => {
        const expected = {
            mode: "develop",
            loggingCallback: src_1.defaultLoggingCallback,
            warningCallback: src_1.defaultWarningCallback,
            exceptionCallback: src_1.defaultExceptionCallback,
        };
        const res = (0, src_1.defaultMccLoggingObject)();
        (0, chai_1.expect)(res).to.be.eql(expected);
    });
    it("should return fillWithDefault with empty object", () => {
        const expected = {
            mode: "develop",
            loggingCallback: src_1.defaultLoggingCallback,
            warningCallback: src_1.defaultWarningCallback,
            exceptionCallback: src_1.defaultExceptionCallback,
        };
        const res = (0, src_1.fillWithDefault)({});
        (0, chai_1.expect)(res).to.be.eql(expected);
    });
    it("should return fillWithDefault with set mode", () => {
        const expected = {
            mode: "off",
            loggingCallback: src_1.defaultLoggingCallback,
            warningCallback: src_1.defaultWarningCallback,
            exceptionCallback: src_1.defaultExceptionCallback,
        };
        const res = (0, src_1.fillWithDefault)({ mode: "off" });
        (0, chai_1.expect)(res).to.be.eql(expected);
    });
    it("should return fillWithDefault with set callbacks", () => {
        function justLikeDefaultLoggingCallback(message) {
            console.log(message);
        }
        function justLikeDefaultWarningCallback(message) {
            console.log(message);
        }
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        function justLikeDefaultExceptionCallback(error, message) {
            console.log(message);
            console.error(error);
            if (error.stack) {
                console.error(error.stack);
            }
        }
        const expected = {
            mode: "off",
            loggingCallback: justLikeDefaultLoggingCallback,
            warningCallback: justLikeDefaultWarningCallback,
            exceptionCallback: justLikeDefaultExceptionCallback,
        };
        const res = (0, src_1.fillWithDefault)({
            mode: "off",
            loggingCallback: justLikeDefaultLoggingCallback,
            warningCallback: justLikeDefaultWarningCallback,
            exceptionCallback: justLikeDefaultExceptionCallback,
        });
        (0, chai_1.expect)(res).to.be.eql(expected);
    });
    it("should eventually return ", async () => {
        await (0, chai_1.expect)((0, src_1.sleepMs)(1000)).to.eventually.be.fulfilled;
    });
    it("should return ", async () => {
        const n = 123;
        const res = (0, src_1.getSimpleRandom)(n);
        (0, chai_1.expect)(res).not.to.equal(n);
    });
    describe("Functions with console.log()", () => {
        it("should log", () => {
            const output = stdout.inspectSync(() => {
                (0, src_1.defaultLoggingCallback)("New message");
            });
            (0, chai_1.expect)(output).to.be.eql(["New message\n"]);
        });
        it("should log", () => {
            const output = stdout.inspectSync(() => {
                (0, src_1.defaultWarningCallback)("New message");
            });
            (0, chai_1.expect)(output).to.be.eql(["New message\n"]);
        });
        it("should log", () => {
            const output = stdout.inspectSync(() => {
                (0, src_1.defaultExceptionCallback)({}, "New message");
            });
            const outputErr = stderr.inspectSync(() => {
                (0, src_1.defaultExceptionCallback)({ stack: "New stack" }, "New message");
            });
            (0, chai_1.expect)(output).to.be.eql(["New message\n"]);
            (0, chai_1.expect)(outputErr[1]).to.be.equal("New stack\n");
            (0, chai_1.expect)(outputErr[0]).contains("New stack");
        });
    });
});
//# sourceMappingURL=utils.test.js.map